function isNewerIpad() {
    // iPads on iOS13+ return as if a desktop Mac
    // so check for maxTouchPoints also.
    return (/Macintosh/i.test(navigator.userAgent) &&
        !!navigator.maxTouchPoints &&
        navigator.maxTouchPoints > 1);
}
function isMobileScreen() {
    const isMobileDevice = 
    // Test Android/iPhone/iPad
    /Android|iPhone|iPad/i.test(navigator.userAgent) || isNewerIpad();
    return isMobileDevice;
}
async function isDeviceUserFacing(deviceId) {
    const devices = await navigator.mediaDevices?.enumerateDevices();
    // Find the video input device with the matching deviceId
    const videoDevice = devices?.find((device) => device.deviceId === deviceId && device.kind === 'videoinput');
    if (videoDevice) {
        // Check if the device label contains the word "back"
        return !videoDevice.label.toLowerCase().includes('back');
    }
    // If the device is not found or not a video input device, return false
    return true;
}
/**
 * Use window.matchMedia to direct landscape orientation
 * screen.orientation is not supported in Safari so we will use
 * media query detection to listen for changes instead.
 * @returns MediaQueryList object
 */
function getLandscapeMediaQuery() {
    return window.matchMedia('(orientation: landscape)');
}

export { getLandscapeMediaQuery, isDeviceUserFacing, isMobileScreen };
