interface SequenceColors {
    sequenceColor: SequenceColorValue;
    prevSequenceColor: SequenceColorValue;
}
export interface SequenceChangeParams extends SequenceColors {
    sequenceIndex: number;
    sequenceStartTime: number;
}
export interface SequenceColorChangeParams extends SequenceColors {
    heightFraction: number;
}
export type SequenceColorValue = `rgb(${string},${string},${string})`;
export interface ColorSequence {
    color: SequenceColorValue;
    downscrollDuration: number;
    flatDisplayDuration: number;
}
type OnSequenceChange = (params: SequenceChangeParams) => void;
export interface StartSequencesParams {
    /**
     * called on sequence change
     */
    onSequenceChange?: OnSequenceChange;
    /**
     * called on sequence color change
     */
    onSequenceColorChange?: (params: SequenceColorChangeParams) => void;
    /**
     * called on sequence start
     */
    onSequenceStart?: () => void;
    /**
     * called on all sequences complete
     */
    onSequencesComplete?: () => void;
}
export type ColorSequences = ColorSequence[];
export declare class ColorSequenceDisplay {
    #private;
    /**
     * Iterates over provided color sequences and executes sequence event callbacks
     *
     * @param {ColorSequences} colorSequences array of color sequences to iterate over
     */
    constructor(colorSequences: ColorSequences);
    /**
     * Start sequence iteration and execute event callbacks
     *
     * @async
     * @param {StartSequencesParams} params Sequence event handlers
     * @returns {Promise<boolean>} Resolves to true when complete
     */
    startSequences(params?: StartSequencesParams): Promise<boolean>;
}
export {};
